/*
	Copyright 2006-2021 The QElectroTech Team
	This file is part of QElectroTech.

	QElectroTech is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 2 of the License, or
	(at your option) any later version.

	QElectroTech is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
*/
#include "reportproperties.h"
#include <QSettings>

ReportProperties::ReportProperties()
{}

/**
	@brief ReportProperties::defaultProperties
	@return the default properties stored in the setting file
*/
QString ReportProperties::defaultProperties()
{
	QSettings settings;
	return(settings.value("diagrameditor/defaultreportlabel", "%f-%l%c").toString());
}
